using UnityEngine;
using System.Collections;
using Holoville.HOTween;

public class MainMenu : MonoBehaviour
{
	public tk2dUIPanel highscores;
	public tk2dUIPanel difficulty;

	private Vector3 defaultPosition;
	private float swipeTime = 1.0f;

	private EaseType anim = EaseType.EaseInOutBack;

	void Awake()
	{
		defaultPosition = gameObject.transform.localPosition;
	}

	void Start()
	{
		HOTween.From(gameObject.transform, swipeTime, "localPosition", new Vector3(defaultPosition.x, 750.0f, defaultPosition.z));
	}

	public void StartClicked()
	{
		HOTween.To(gameObject.transform, swipeTime, new TweenParms().Prop("localPosition", new Vector3(defaultPosition.x, -650.0f, defaultPosition.z)).Ease(anim).OnComplete(StartGame));
	}

	public void QuitClicked()
	{
		Application.Quit();
	}

	public void DifficultyClicked()
	{
		HOTween.To(gameObject.transform, swipeTime, new TweenParms().Prop("localPosition", new Vector3(-800, defaultPosition.y, defaultPosition.z)).Ease(anim).OnComplete(Dismiss));
		difficulty.Show(OnDifficultyEnd);
	}

	public void HighScoreClicked()
	{
		HOTween.To(gameObject.transform, swipeTime, new TweenParms().Prop("localPosition", new Vector3(-800, defaultPosition.y, defaultPosition.z)).Ease(anim).OnComplete(Dismiss));
		highscores.Show(OnHighScoresEnd);
	}

	private void StartGame()
	{
		gameObject.SetActive(false);
		MainGameScript.Instance.StartGame(OnGameEnd);
	}

	private void Dismiss()
	{
		gameObject.SetActive(false);
	}

	private void OnDifficultyEnd(tk2dUIPanel panel, int diff)
	{
		gameObject.SetActive(true);
		MainGameScript.Instance.Difficulty = diff;
		HOTween.To(gameObject.transform, swipeTime, new TweenParms().Prop("localPosition", defaultPosition).Ease(anim));
	}

	private void OnHighScoresEnd(tk2dUIPanel panel, int n)
	{
		gameObject.SetActive(true);
		HOTween.To(gameObject.transform, swipeTime, new TweenParms().Prop("localPosition", defaultPosition).Ease(anim));
	}

	private void OnGameEnd(int n)
	{	
		gameObject.SetActive(true);
		HOTween.To(gameObject.transform, swipeTime, new TweenParms().Prop("localPosition", defaultPosition).Ease(anim));
	}
}
